@@ -15,4 +15,11 @@ def test_download():
 
 def test_sub01():
     rfs = RFStation('ex-rfani/SC.LTA')
-    rfs.jointani(3, 8, tlen=3.5, stack_baz_val=10, weight=[0.4, 0.4, 0.2])
\ No newline at end of file
+    rfs.jointani(3, 8, tlen=3.5, stack_baz_val=10, weight=[0.4, 0.4, 0.2])
+
+
+def test_sub02():
+    rfs = RFStation('ex-rfani/SC.LTA')
+    rfs.moveoutcorrect()
+    rfs.psrf2depth()
+    rfs.psrf_1D_raytracing()
